`jcal` is a package for Japanese holiday.
https://www8.cao.go.jp/chosei/shukujitsu/gaiyou.html
::

   print(sorted(holiday(2019)))
   >>>
   [datetime.date(2019, 1, 1), datetime.date(2019, 1, 14), datetime.date(2019, 2, 11),
    datetime.date(2019, 3, 21), datetime.date(2019, 4, 29), datetime.date(2019, 4, 30),
    datetime.date(2019, 5, 1), datetime.date(2019, 5, 2), datetime.date(2019, 5, 3),
    datetime.date(2019, 5, 4), datetime.date(2019, 5, 5), datetime.date(2019, 5, 6),
    datetime.date(2019, 7, 15), datetime.date(2019, 8, 12), datetime.date(2019, 9, 16),
    datetime.date(2019, 9, 23), datetime.date(2019, 10, 14), datetime.date(2019, 10, 22),
    datetime.date(2019, 11, 4), datetime.date(2019, 11, 23)]

Requirements
------------
* Python 3

Features
--------
* nothing

Setup
-----
::

   $ pip install jcal

History
-------
0.0.1 (2016-2-5)
~~~~~~~~~~~~~~~~~~
* first release
